# Surreal Documentation
## Tutorials
We recommend following the local mode guide first and then go to the Kubernetes mode.  
* [Local mode](surreal_tmux.md)  
* [Kubernetes mode on Google Cloud](surreal_kube_gke.md)  

## Algorithms
* [Surreal DDPG](ddpg.md)  
* [Surreal PPO](ddpg.md)  

## References
* [Environments](env.md)  
* [Config file](yaml_config.md)  
* [Creation settings for Kubernetes mode](creation_settings.md)  

## Development
* [Contribute to Surreal](contributing.md)
* [Using Surreal as part of your project](importing.md)

## Customizing Surreal

## Issues
* [FAQ](faq.md)
* [Reporting Issues](reporting_issues.md)